#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

__docformat__ = 'restructuredtext'

from persistent import Persistent
from zope.location import Location
from zope.schema.fieldproperty import FieldProperty

from onf_website.component.paragraph.skin.interfaces.html import \
    IHTMLParagraphAccordionRendererSettings
from pyams_content.component.paragraph.interfaces.html import IHTMLParagraph
from pyams_content.features.renderer import IContentRenderer
from pyams_default_theme.component.paragraph.html import HTMLParagraphDefaultRenderer
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config, get_annotation_adapter
from pyams_utils.factory import factory_config

from onf_website import _


HTML_PARAGRAPH_ACCORDION_RENDERER_SETTINGS_KEY = 'pyams_content.html.renderer:accordion'


@factory_config(IHTMLParagraphAccordionRendererSettings)
class HTMLParagraphAccordionRendererSettings(Persistent, Location):
    """HTML paragraph accordion renderer settings"""

    collapsed = FieldProperty(IHTMLParagraphAccordionRendererSettings['collapsed'])


@adapter_config(context=IHTMLParagraph,
                provides=IHTMLParagraphAccordionRendererSettings)
def html_paragraph_accordion_renderer_settings_factory(context):
    """HTML paragraph accordion renderer settings factory"""
    return get_annotation_adapter(context, HTML_PARAGRAPH_ACCORDION_RENDERER_SETTINGS_KEY,
                                  IHTMLParagraphAccordionRendererSettings)


@adapter_config(name='accordion',
                context=(IHTMLParagraph, IPyAMSLayer),
                provides=IContentRenderer)
@template_config(template='templates/html-accordion.pt', layer=IPyAMSLayer)
class HTMLParagraphAccordionRenderer(HTMLParagraphDefaultRenderer):
    """HTML paragraph accordion renderer"""

    label = _("Rich text accordion renderer")
    weight = 30

    settings_interface = IHTMLParagraphAccordionRendererSettings
